LoginViewModel class

Constructors

LoginViewModel({required AuthRepository authRepository})

Properties

email → FlutterSignal<Email>
final
hashCode int
The hash code for this object.
no setterinherited
isValid → FlutterComputed<bool>
latefinal
loginCommand Command0
latefinal
password → FlutterSignal<Password>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
emailChanged(String newEmail) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passwordChanged(String newPassword) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited