AuthStatus enum

Inheritance
Available extensions

Values

unknown → const AuthStatus
unauthenticated → const AuthStatus
authenticated → const AuthStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isAuthenticated bool

Available on AuthStatus, provided by the AuthStatusX extension

no setter
isUnauthenticated bool

Available on AuthStatus, provided by the AuthStatusX extension

no setter
isUnknown bool

Available on AuthStatus, provided by the AuthStatusX extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthStatus>
A constant List of the values in this enum, in order of their declaration.