User class abstract

Represents User

Available extensions
Annotations
  • @freezed

Constructors

User({required String id, required String email, required String name})
Represents User
const
factory

Properties

copyWith → $UserCopyWith<User>
Create a copy of User with the given fields replaced by the non-null parameter values.
no setterinherited
email String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
isEmpty bool
Check whether user is empty
no setter
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_User value)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_User value)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_User value)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String email, String name)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String email, String name)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String email, String name)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const User
Represents an empty user