homeBuilder abstract method
The home should have button which redirects to profile route
Implementation
Widget homeBuilder(BuildContext context, GoRouterState state);
The home should have button which redirects to profile route
Widget homeBuilder(BuildContext context, GoRouterState state);