AptofShellRouter class abstract

This class uses a shell navigation from go router

Inheritance

Constructors

AptofShellRouter(AuthRepository authRepository)

Properties

authRepository AuthRepository
finalinherited
authRoutes List<GoRoute>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

branches() List<StatefulShellBranch>
changePasswordBuilder(BuildContext context, GoRouterState state) Widget
inherited
createRouter() → GoRouter
override
destinations(BuildContext context) List<NavigationDestination>
forgotBuilder(BuildContext context, GoRouterState state) Widget
inherited
loginBuilder(BuildContext context, GoRouterState state) Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
profileBranch() → StatefulShellBranch
profileBuilder(BuildContext context, GoRouterState state) Widget
inherited
profileDestination(BuildContext context) NavigationDestination
redirect(BuildContext context, GoRouterState state) FutureOr<String?>
inherited
splashBuilder(BuildContext context, GoRouterState state) Widget
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited