BaseRouter class abstract
- Implementers
Constructors
- BaseRouter(AuthRepository authRepository)
Properties
- authRepository → AuthRepository
-
final
-
authRoutes
→ List<
GoRoute> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changePasswordBuilder(
BuildContext context, GoRouterState state) → Widget -
createRouter(
) → GoRouter -
forgotBuilder(
BuildContext context, GoRouterState state) → Widget -
loginBuilder(
BuildContext context, GoRouterState state) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
profileBuilder(
BuildContext context, GoRouterState state) → Widget -
redirect(
BuildContext context, GoRouterState state) → FutureOr< String?> -
splashBuilder(
BuildContext context, GoRouterState state) → Widget -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited