SplashViewModel class

Constructors

SplashViewModel({required UpdaterRepository updaterRepository})

Properties

hashCode int
The hash code for this object.
no setterinherited
info UpdateInfo
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionCommand Command0
latefinal

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited