ApiUpdateInfo class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ApiUpdateInfo({required String androidLink, required String windowsLink, required String version, String? id, @TimestampConverter() DateTime? createdAt, @TimestampConverter() DateTime? updatedAt})
-
constfactory
-
ApiUpdateInfo.fromFirestore(DocumentSnapshot<
Map< snapshot)String, dynamic> > -
factory
-
ApiUpdateInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- androidLink → String
-
no setterinherited
-
copyWith
→ $ApiUpdateInfoCopyWith<
ApiUpdateInfo> -
Create a copy of ApiUpdateInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
- version → String
-
no setterinherited
- windowsLink → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ApiUpdateInfo value)) → TResult -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ApiUpdateInfo value)?) → TResult? -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ApiUpdateInfo value)?, {required TResult orElse()}) → TResult -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ApiUpdateInfo to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)) → TResult -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)?) → TResult? -
Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited