PaginatedResult<T> class abstract

Available extensions
Annotations
  • @freezed

Constructors

PaginatedResult({required List<T> items, required bool hasMore, DocumentSnapshot<Object?>? lastDocument})
factory

Properties

copyWith → $PaginatedResultCopyWith<T, PaginatedResult<T>>
Create a copy of PaginatedResult with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
no setterinherited
items List<T>
no setterinherited
lastDocument → DocumentSnapshot<Object?>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaginatedResult<T> value)) → TResult

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaginatedResult<T> value)?) → TResult?

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaginatedResult<T> value)?, {required TResult orElse()}) → TResult

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<T> items, DocumentSnapshot<Object?>? lastDocument, bool hasMore)?, {required TResult orElse()}) → TResult

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<T> items, DocumentSnapshot<Object?>? lastDocument, bool hasMore)) → TResult

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<T> items, DocumentSnapshot<Object?>? lastDocument, bool hasMore)?) → TResult?

Available on PaginatedResult<T>, provided by the PaginatedResultPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited