AptofTheme class

Constructors

AptofTheme({required Color seedColor})

Properties

colorScheme ColorScheme
no setter
dark ThemeData
no setter
hashCode int
The hash code for this object.
no setterinherited
inputDecorationTheme InputDecorationTheme
no setter
light ThemeData
no setter
pageTransitionsTheme PageTransitionsTheme
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seedColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited