AptofRouter class abstract
- Inheritance
-
- Object
- BaseRouter
- AptofRouter
Constructors
- AptofRouter(AuthRepository authRepository)
Properties
- authRepository → AuthRepository
-
finalinherited
-
authRoutes
→ List<
GoRoute> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
→ List<
GoRoute> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changePasswordBuilder(
BuildContext context, GoRouterState state) → Widget -
inherited
-
createRouter(
) → GoRouter -
override
-
forgotBuilder(
BuildContext context, GoRouterState state) → Widget -
inherited
-
homeBuilder(
BuildContext context, GoRouterState state) → Widget - The home should have button which redirects to profile route
-
loginBuilder(
BuildContext context, GoRouterState state) → Widget -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
profileBuilder(
BuildContext context, GoRouterState state) → Widget -
inherited
-
redirect(
BuildContext context, GoRouterState state) → FutureOr< String?> -
inherited
-
splashBuilder(
BuildContext context, GoRouterState state) → Widget -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited