ApiUpdateInfo class abstract

Available extensions
Annotations
  • @freezed

Constructors

ApiUpdateInfo({required String androidLink, required String windowsLink, required String version, String? id, @TimestampConverter() DateTime? createdAt, @TimestampConverter() DateTime? updatedAt})
const
factory
ApiUpdateInfo.fromFirestore(DocumentSnapshot<Map<String, dynamic>> snapshot)
factory
ApiUpdateInfo.fromJson(Map<String, dynamic> json)
factory

Properties

no setterinherited
copyWith → $ApiUpdateInfoCopyWith<ApiUpdateInfo>
Create a copy of ApiUpdateInfo with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
no setterinherited
version String
no setterinherited
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ApiUpdateInfo value)) → TResult

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApiUpdateInfo value)?) → TResult?

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApiUpdateInfo value)?, {required TResult orElse()}) → TResult

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ApiUpdateInfo to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)) → TResult

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String androidLink, String windowsLink, String version, String? id, DateTime? createdAt, DateTime? updatedAt)?) → TResult?

Available on ApiUpdateInfo, provided by the ApiUpdateInfoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited