UpdateInfo class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- UpdateInfo({required String availableVersion, required String link, required bool hasUpdate, required String installedVersion})
-
constfactory
- UpdateInfo.empty({String installedVersion = ''})
-
factory
Properties
- availableVersion → String
-
no setterinherited
-
copyWith
→ $UpdateInfoCopyWith<
UpdateInfo> -
Create a copy of UpdateInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUpdate → bool
-
no setterinherited
- installedVersion → String
-
no setterinherited
- link → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_UpdateInfo value)) → TResult -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_UpdateInfo value)?) → TResult? -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_UpdateInfo value)?, {required TResult orElse()}) → TResult -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String availableVersion, String link, bool hasUpdate, String installedVersion)?, {required TResult orElse()}) → TResult -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String availableVersion, String link, bool hasUpdate, String installedVersion)) → TResult -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String availableVersion, String link, bool hasUpdate, String installedVersion)?) → TResult? -
Available on UpdateInfo, provided by the UpdateInfoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited